/// <reference types="node" />
import { Emitter, Event } from '@theia/core/lib/common/event';
export interface BufferingStreamOptions {
    /**
     * Max size in bytes of the chunks being emitted.
     */
    maxChunkSize?: number;
    /**
     * Amount of time in milliseconds to wait between the moment we start
     * buffering data and when we emit the buffered chunk.
     */
    emitInterval?: number;
}
/**
 * This component will buffer whatever is pushed to it and emit chunks back
 * every {@link BufferingStreamOptions.emitInterval}. It will also ensure that
 * the emitted chunks never exceed {@link BufferingStreamOptions.maxChunkSize}.
 */
export declare class BufferingStream<T> {
    protected buffer?: T;
    protected timeout?: NodeJS.Timeout;
    protected maxChunkSize: number;
    protected emitInterval: number;
    protected onDataEmitter: Emitter<T>;
    protected readonly concat: (left: T, right: T) => T;
    protected readonly slice: (what: T, start?: number, end?: number) => T;
    protected readonly length: (what: T) => number;
    constructor(options: BufferingStreamOptions | undefined, concat: (left: T, right: T) => T, slice: (what: T, start?: number, end?: number) => T, length: (what: T) => number);
    get onData(): Event<T>;
    push(chunk: T): void;
    dispose(): void;
    protected emitBufferedChunk(): void;
}
export declare class StringBufferingStream extends BufferingStream<string> {
    constructor(options?: BufferingStreamOptions);
}
export declare class BufferBufferingStream extends BufferingStream<Buffer> {
    constructor(options?: BufferingStreamOptions);
}
//# sourceMappingURL=buffering-stream.d.ts.map